@@ -1,4 +1,4 @@
-################################################################################
+################################################################################ 
 #' Scores for FLUXNET reference data in NetCDF format
 #' @description This function compares model output against
 #' FLUXNET measurements in NetCDF format. The performance of a model is
@@ -43,7 +43,7 @@
 #' the reference data
 #' (mean, \eqn{ref.mean}; interannual-variability, \eqn{ref.iav}; month of annual cycle maximum, \eqn{ref.max.month}),
 #' statistical metrics
-#' (bias, \eqn{bias}; root mean square error, \eqn{rmse}; time difference of the annual cycle maximum, \eqn{phase}),
+#' (bias, \eqn{bias}; centralized root mean square error, \eqn{crmse}; time difference of the annual cycle maximum, \eqn{phase}),
 #' and scores
 #' (bias score, \eqn{bias.score}; root mean square error score, \eqn{rmse.score}; inter-annual variability score \eqn{iav.score}; annual cycle score (\eqn{phase.score}).
 #'
@@ -106,14 +106,15 @@
 #' shp.filename, my.xlim, my.ylim)
 #' }
 #' @export
-scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.conv.mod, unit.conv.ref, variable.unit, score.weights,
-    rotate.me = TRUE, irregular = FALSE, my.projection = "+proj=longlat +ellps=WGS84", shp.filename = system.file("extdata/ne_110m_land/ne_110m_land.shp",
-        package = "amber"), my.xlim = c(-180, 180), my.ylim = c(-60, 85), plot.width = 8, plot.height = 3.8, numCores = 2, outputDir = FALSE) {
-
+scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.conv.mod, unit.conv.ref, variable.unit, score.weights, 
+    rotate.me = TRUE, irregular = FALSE, my.projection = "+proj=longlat +ellps=WGS84", shp.filename = system.file("extdata/ne_110m_land/ne_110m_land.shp", 
+        package = "amber"), my.xlim = c(-180, 180), my.ylim = c(-60, 85), plot.width = 8, plot.height = 3.8, numCores = 2, 
+    outputDir = FALSE) {
+    
     # (I) Data preparation -----------------------------------------------------
-
+    
     # (1) Reproject data from an irregular to a regular grid if 'irregular=TRUE'
-
+    
     if (irregular == TRUE) {
         regular <- "+proj=longlat +ellps=WGS84"
         rotated <- my.projection
@@ -124,7 +125,7 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         variable.name <- ifelse(variable.name == "burntFractionAll", "burnt", variable.name)  # rename burntFractionAll to shorter name
         variable.name <- toupper(variable.name)  # make variable name upper-case
         ncdf4::nc_close(nc)
-
+        
         # process model data
         my.nc <- nc.mod
         nc <- ncdf4::nc_open(my.nc)
@@ -132,7 +133,7 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         lon <- ncdf4::ncvar_get(nc, "lon")
         lat <- ncdf4::ncvar_get(nc, "lat")
         time <- ncdf4::ncvar_get(nc, "time")
-        #
+        # 
         nCol <- base::length(lon[, 1])
         nRow <- base::length(lon[1, ])
         nTime <- base::length(time)
@@ -146,10 +147,10 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         end.date <- max(dates)
         start.date <- format(as.Date(start.date), "%Y-%m")
         end.date <- format(as.Date(end.date), "%Y-%m")
-
+        
         lon <- base::matrix(lon, ncol = 1)
         lat <- base::matrix(lat, ncol = 1)
-
+        
         lonLat <- base::data.frame(lon, lat)
         sp::coordinates(lonLat) <- ~lon + lat
         raster::projection(lonLat) <- regular
@@ -174,7 +175,7 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         mod <- myStack
         start.date.mod <- start.date
         end.date.mod <- end.date
-
+        
         # process reference data
         nc <- ncdf4::nc_open(nc.ref)
         variable.name.ref <- names(nc[["var"]])
@@ -192,10 +193,10 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         # convert data to data frame
         lon <- ncdf4::ncvar_get(nc, varid = "lon")
         lat <- ncdf4::ncvar_get(nc, varid = "lat")
-
+        
         lon <- base::matrix(lon, ncol = 1)
         lat <- base::matrix(lat, ncol = 1)
-
+        
         # reproject coordinates to rotated grid
         lonLat <- base::data.frame(lon, lat)
         sp::coordinates(lonLat) <- ~lon + lat
@@ -210,11 +211,11 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         site.id <- paste("site", seq(1, nrow(data), 1), sep = "_")
         rownames(data) <- site.id
         ref <- data
-
+        
     } else {
-
+        
         # (2) Process data if 'irregular=FALSE' --------------------------------
-
+        
         # model data
         nc <- ncdf4::nc_open(nc.mod)
         variable.name <- names(nc[["var"]])
@@ -252,16 +253,17 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         site.id <- paste("site", seq(1, nrow(data), 1), sep = "_")
         rownames(data) <- site.id
         ref <- data
-
+        
     }
-
+    
     #---------------------------------------------------------------------------
-
+    
     # find common time period
     start.date <- max(start.date.mod, start.date.ref)
     end.date <- min(end.date.mod, end.date.ref)
     # subset common time period for model data
-    mod <- mod[[which(format(as.Date(raster::getZ(mod)), "%Y-%m") >= start.date & format(as.Date(raster::getZ(mod)), "%Y-%m") <= end.date)]]
+    mod <- mod[[which(format(as.Date(raster::getZ(mod)), "%Y-%m") >= start.date & format(as.Date(raster::getZ(mod)), "%Y-%m") <= 
+        end.date)]]
     # subset common time period for reference data get a sequence of common dates
     dates <- seq(from = as.Date(paste(start.date, "15", sep = "-")), to = as.Date(paste(end.date, "15", sep = "-")), by = "month")
     dates <- format(as.Date(dates), "%Y-%m")
@@ -271,8 +273,8 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     index <- seq(1, length(dates.ref), 1)
     dates.ref <- data.frame(index, dates.ref)
     colnames(dates.ref) <- c("index", "dates")
-    ## merge common dates and reference dates the index will be used to subset the reference data set if the time covered by the
-    ## reference data exceeds the time covered by the model data
+    ## merge common dates and reference dates the index will be used to subset the reference data set if the time covered by
+    ## the reference data exceeds the time covered by the model data
     column.id <- merge(dates.ref, common.dates, by = "dates")
     column.id <- column.id$index
     ref <- data.frame(ref[2 + column.id])  # 2+ because column 1 and 2 are are lon and lat
@@ -295,8 +297,8 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     meta.data.mod <- paste(variable.name, mod.id, "from", start.date, "to", end.date, sep = "_")
     meta.data.ref <- paste(variable.name, ref.id, "from", start.date, "to", end.date, sep = "_")
     meta.data.com <- paste(variable.name, mod.id, "vs", ref.id, "from", start.date, "to", end.date, sep = "_")
-    # statistical analysis the time period of the reference data varies among sites some sites are located in the model ocean exclude
-    # data in one data set that is not available in the other data set
+    # statistical analysis the time period of the reference data varies among sites some sites are located in the model
+    # ocean exclude data in one data set that is not available in the other data set
     mask.mod <- (mod - mod + 1)
     mask.ref <- (ref - ref + 1)
     mask <- mask.mod * mask.ref
@@ -382,17 +384,18 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     mod.max.month.scalar <- mean(mod.max.month[, 1], na.rm = TRUE)  # global mean value
     ref.max.month.scalar <- mean(ref.max.month[, 1], na.rm = TRUE)  # global mean value
     # (4) interannual variability
-
-    # This approach assumes that all data start in Jan all months after the last Dec will be dropped if data does not end in Dec
+    
+    # This approach assumes that all data start in Jan all months after the last Dec will be dropped if data does not end in
+    # Dec
     mod.anom <- intFun.anom.mly(mod, mod.clim.mly.mm)
     ref.anom <- intFun.anom.mly(ref, ref.clim.mly.mm)
     mod.iav <- apply(mod.anom, 2, intFun.iav)
     ref.iav <- apply(ref.anom, 2, intFun.iav)
-
+    
     # set values close to zero to NA
     ref.iav.na <- ref.iav
     ref.iav.na[ref.iav.na < 10^(-5)] <- NA
-
+    
     epsilon_iav <- abs((mod.iav - ref.iav))/ref.iav.na  # I changed Eq. 26 so that epsilon_iav > =  0
     iav.score <- exp(-epsilon_iav)  # iav score as a function of space
     S_iav_not.weighted <- mean(iav.score, na.rm = TRUE)  # scalar score (not weighted)
@@ -404,7 +407,7 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     mod.iav.scalar <- mean(mod.iav, na.rm = TRUE)  # global mean value
     ref.iav.scalar <- mean(ref.iav, na.rm = TRUE)  # global mean value
     epsilon_iav.scalar <- mean(epsilon_iav, na.rm = TRUE)  # global mean value
-
+    
     # (5) dist
     mod.sigma.scalar <- sd(mod.mean, na.rm = TRUE)  # standard deviation of period mean data
     ref.sigma.scalar <- sd(ref.mean, na.rm = TRUE)  # standard deviation of period mean data
@@ -426,8 +429,8 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     S_phase <- S_phase_not.weighted
     S_iav <- S_iav_not.weighted
     # weight importance of statisitcal metrics and compute overall score
-    S_overall <- (w.bias * S_bias + w.rmse * S_rmse + w.phase * S_phase + w.iav * S_iav + w.dist * S_dist)/(w.bias + w.rmse + w.phase +
-        w.iav + w.dist)
+    S_overall <- (w.bias * S_bias + w.rmse * S_rmse + w.phase * S_phase + w.iav * S_iav + w.dist * S_dist)/(w.bias + w.rmse + 
+        w.phase + w.iav + w.dist)
     scores <- data.frame(variable.name, ref.id, S_bias, S_rmse, S_phase, S_iav, S_dist, S_overall)
     scores_not.weighted <- scores
     # weighted (except for S_dist)
@@ -435,11 +438,11 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     S_rmse <- S_rmse_weighted
     S_phase <- S_phase_weighted
     S_iav <- S_iav_weighted
-    S_overall <- (w.bias * S_bias + w.rmse * S_rmse + w.phase * S_phase + w.iav * S_iav + w.dist * S_dist)/(w.bias + w.rmse + w.phase +
-        w.iav + w.dist)
+    S_overall <- (w.bias * S_bias + w.rmse * S_rmse + w.phase * S_phase + w.iav * S_iav + w.dist * S_dist)/(w.bias + w.rmse + 
+        w.phase + w.iav + w.dist)
     scores <- data.frame(variable.name, ref.id, S_bias, S_rmse, S_phase, S_iav, S_dist, S_overall)
     scores_weighted <- scores
-    #
+    # 
     scores <- rbind(scores_not.weighted, scores_weighted)
     rownames(scores) <- c("not.weighted", "weighted")
     if (outputDir != FALSE) {
@@ -454,17 +457,17 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         utils::write.table(all.score.values, paste(outputDir, "/", "allscorevalues", "-", variable.name, "-", ref.id, sep = ""))
     }
     # selected score inputs
-    scoreinputs <- data.frame(long.name, variable.name, ref.id, variable.unit, mod.mean.scalar, ref.mean.scalar, bias.scalar, ref.sd.scalar,
-        epsilon_bias.scalar, S_bias_not.weighted, rmse.scalar, crmse.scalar, ref.sd.scalar, epsilon_rmse.scalar, S_rmse_not.weighted,
-        mod.max.month.scalar, ref.max.month.scalar, phase.scalar, S_phase_not.weighted, mod.iav.scalar, ref.iav.scalar, epsilon_iav.scalar,
-        S_iav_not.weighted, mod.sigma.scalar, ref.sigma.scalar, sigma, R, S_dist)
+    scoreinputs <- data.frame(long.name, variable.name, ref.id, variable.unit, mod.mean.scalar, ref.mean.scalar, bias.scalar, 
+        ref.sd.scalar, epsilon_bias.scalar, S_bias_not.weighted, rmse.scalar, crmse.scalar, ref.sd.scalar, epsilon_rmse.scalar, 
+        S_rmse_not.weighted, mod.max.month.scalar, ref.max.month.scalar, phase.scalar, S_phase_not.weighted, mod.iav.scalar, 
+        ref.iav.scalar, epsilon_iav.scalar, S_iav_not.weighted, mod.sigma.scalar, ref.sigma.scalar, sigma, R, S_dist)
     if (outputDir != FALSE) {
         utils::write.table(scoreinputs, paste(outputDir, "/", "scoreinputs", "_", meta.data.com, sep = ""))
     }
     # min.max.int
     mmi.bias <- intFun.min.max.int.bias(bias)
     mmi.bias.score <- c(0, 1, 0.1)
-    mmi.rmse <- intFun.min.max.int(rmse)
+    mmi.crmse <- intFun.min.max.int(crmse)
     mmi.rmse.score <- c(0, 1, 0.1)
     mmi.phase <- c(0, 6, 1)
     mmi.phase.score <- c(0, 1, 0.1)
@@ -474,17 +477,17 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     mmi.max.month <- c(1, 12, 1)
     mmi.iav <- intFun.min.max.int.mod.ref(mod.iav, ref.iav)
     # add metadata:
-
+    
     # 1. figure title (e.g. Mean_nee_ModID_123_from_1982-01_to_2008-12)
-
+    
     # 2. min, max, interval used in legend (e.g. 0, 1, 0.1)
-
+    
     # 3. legend bar text (e.g. 'score (-)')
     attr(mod.mean, "metadata") <- list(paste("Mean", meta.data.mod, sep = "_"), mmi.mean, variable.unit)
     attr(ref.mean, "metadata") <- list(paste("Mean", meta.data.ref, sep = "_"), mmi.mean, variable.unit)
     attr(bias, "metadata") <- list(paste("Bias", meta.data.com, sep = "_"), mmi.bias, variable.unit)
     attr(bias.score, "metadata") <- list(paste("Bias_score", meta.data.com, sep = "_"), mmi.bias.score, "score (-)")
-    attr(rmse, "metadata") <- list(paste("RMSE", meta.data.com, sep = "_"), mmi.rmse, variable.unit)
+    attr(crmse, "metadata") <- list(paste("CRMSE", meta.data.com, sep = "_"), mmi.crmse, variable.unit)
     attr(rmse.score, "metadata") <- list(paste("RMSE_score", meta.data.com, sep = "_"), mmi.rmse.score, "score (-)")
     attr(mod.max.month, "metadata") <- list(paste("Month_with_max", meta.data.mod, sep = "_"), mmi.max.month, "month")
     attr(ref.max.month, "metadata") <- list(paste("Month_with_max", meta.data.ref, sep = "_"), mmi.max.month, "month")
@@ -494,15 +497,15 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
     attr(ref.iav, "metadata") <- list(paste("IAV", meta.data.ref, sep = "_"), mmi.iav, variable.unit)
     attr(iav.score, "metadata") <- list(paste("IAV_score", meta.data.com, sep = "_"), mmi.iav.score, "score (-)")
     # write data to file
-    stat.metric <- data.frame(lon, lat, mod.mean, ref.mean, bias, bias.score, rmse, rmse.score, mod.max.month, ref.max.month, phase,
-        phase.score, mod.iav, ref.iav, iav.score)
-    colnames(stat.metric) <- c("lon", "lat", "mod.mean", "ref.mean", "bias", "bias.score", "rmse", "rmse.score", "mod.max.month",
+    stat.metric <- data.frame(lon, lat, mod.mean, ref.mean, bias, bias.score, crmse, rmse.score, mod.max.month, ref.max.month, 
+        phase, phase.score, mod.iav, ref.iav, iav.score)
+    colnames(stat.metric) <- c("lon", "lat", "mod.mean", "ref.mean", "bias", "bias.score", "crmse", "rmse.score", "mod.max.month", 
         "ref.max.month", "phase", "phase.score", "mod.iav", "ref.iav", "iav.score")
     my.filename <- paste(variable.name, "FLUXNET", sep = "_")
     if (outputDir != FALSE) {
         utils::write.table(stat.metric, paste(outputDir, my.filename, sep = "/"))
     }
-
+    
     land <- intFun.coast(my.xlim, my.ylim, my.projection, shp.filename)  # reproject coastline
     # loop through all layers of the raster stack
     lon2 <- stat.metric$lon
@@ -535,32 +538,32 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         my.col <- viridis::viridis(n = length(my.breaks) - 1, direction = -1)
         my.col.bias <- scico::scico(n = length(my.breaks) - 1, palette = "vik")
         my.col.phase <- grDevices::rainbow(n = length(my.breaks) - 1)
-        if (i == 5)
+        if (i == 5) 
             {
                 my.col <- my.col.bias
             }  # divergent color scheme for bias plots
-        if (i == 9)
+        if (i == 9) 
             {
                 my.col <- my.col.phase
             }  # circular color scheme for phase
-        if (i == 10)
+        if (i == 10) 
             {
                 my.col <- my.col.phase
             }  # circular color scheme for phase
-        if (i == 11)
+        if (i == 11) 
             {
                 my.col <- my.col.phase
             }  # circular color scheme for phase
-
+        
         my.axis.args <- list(at = my.labels, labels = my.labels, cex.axis = 1)
         my.legend.args <- list(text = legend.bar.text, side = 2, font = 1, line = 1, cex = 1)
-
+        
         colors <- cut(values$values, breaks = my.breaks, labels = my.col, include.lowest = TRUE)
         colors <- toString(colors)
         colors <- unlist(strsplit(colors, split = ", "))
-
+        
         # plot
-        oldpar <- graphics::par(mfrow = c(1,2))
+        oldpar <- graphics::par(mfrow = c(1, 2))
         on.exit(graphics::par(oldpar))
         my.plotname <- paste(my.filename, cname, sep = "_")
         my.plotname <- gsub("_", "-", my.plotname)
@@ -579,7 +582,7 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
         dummy <- matrix(dummy, nrow = 180)
         dummy <- raster::raster(dummy)
         raster::extent(dummy) <- myExtent
-        raster::plot(dummy, col = NA, xlim = my.xlim, ylim = my.ylim, main = paste(long.name, my.title, sep = "\n"), axes = FALSE,
+        raster::plot(dummy, col = NA, xlim = my.xlim, ylim = my.ylim, main = paste(long.name, my.title, sep = "\n"), axes = FALSE, 
             legend = FALSE)
         raster::plot(land, col = "grey", border = NA, add = TRUE)
         graphics::points(data, pch = 16, col = colors)
@@ -587,12 +590,12 @@ scores.fluxnet.nc <- function(long.name, nc.mod, nc.ref, mod.id, ref.id, unit.co
             graphics::axis(1, labels = TRUE, tcl = 0.3)
             graphics::axis(2, labels = TRUE, tcl = 0.3, las = 2)
         }
-        plot(dummy, legend.only = TRUE, col = my.col, breaks = my.breaks, axis.args = my.axis.args, legend.args = my.legend.args,
+        plot(dummy, legend.only = TRUE, col = my.col, breaks = my.breaks, axis.args = my.axis.args, legend.args = my.legend.args, 
             legend.width = 1.5, legend.shrink = 1, font = 1)
         if (outputDir != FALSE) {
             grDevices::dev.off()
         }
     }
-
+    
 }
 
